@@ -10,11 +10,13 @@ from .resources import artifact
 from .resources import user
 from .resources import refresh_token
 
+from .resources import test_run_v1
+
 
 class ZafiraClient:
+    # deprecated API endpoints
     DEFAULT_USER = "anonymous"
     STATUS_PATH = "/api/status"
-    REFRESH_TOKEN_PATH = "/api/iam/v1/auth/refresh"
     LOGIN_PATH = "/api/auth/login"
     TEST_SUITES_PATH = "/api/tests/suites"
     TEST_CASES_PATH = "/api/tests/cases"
@@ -32,6 +34,10 @@ class ZafiraClient:
     PROJECT_PATH = "/api/projects"
     GET_SETTING_TOOL_PATH = "/api/settings/tool/{}"
 
+    # actual API endpoints
+    TEST_RUNS_PATH_V1 = '/api/reporting/v1/test-runs?projectKey={}'
+    REFRESH_TOKEN_PATH = "/api/iam/v1/auth/refresh"
+
     INSTANCE = None
 
     def __new__(cls, service_url):
@@ -84,23 +90,32 @@ class ZafiraClient:
         return self.api.send_post(ZafiraClient.JOBS_PATH, job, headers=self.init_auth_headers(),
                                   default_err_msg="Unable to create job")
 
-    def start_test_run(self, job_id, test_suite_id, build_number, started_by=Initiator.SCHEDULER.value,  # noqa F405
-                       driver_mode=DriverMode.METHOD_MODE.value, config=None, blocker=None,  # noqa F405
-                       work_item=None, status=None, project=None, known_issue=None):
-        test_run["jobId"] = job_id
-        test_run["testSuiteId"] = test_suite_id
-        test_run["buildNumber"] = build_number
-        test_run["startedBy"] = started_by
-        test_run["driverMode"] = driver_mode
-        test_run["blocker"] = blocker
-        test_run["workItem"] = work_item
-        test_run["status"] = status
-        test_run["project"] = project
-        test_run["knownIssue"] = known_issue
-        test_run["configXML"] = config
-        return self.api.send_post(ZafiraClient.TEST_RUNS_PATH, test_run, headers=self.init_auth_headers(),
+    # def start_test_run(self, job_id, test_suite_id, build_number, started_by=Initiator.SCHEDULER.value,  # noqa F405
+    #                    driver_mode=DriverMode.METHOD_MODE.value, config=None, blocker=None,  # noqa F405
+    #                    work_item=None, status=None, project=None, known_issue=None):
+    #     test_run["jobId"] = job_id
+    #     test_run["testSuiteId"] = test_suite_id
+    #     test_run["buildNumber"] = build_number
+    #     test_run["startedBy"] = started_by
+    #     test_run["driverMode"] = driver_mode
+    #     test_run["blocker"] = blocker
+    #     test_run["workItem"] = work_item
+    #     test_run["status"] = status
+    #     test_run["project"] = project
+    #     test_run["knownIssue"] = known_issue
+    #     test_run["configXML"] = config
+    #     return self.api.send_post(ZafiraClient.TEST_RUNS_PATH, test_run, headers=self.init_auth_headers(),
+    #                               default_err_msg="Unable to start test run")
+
+    def start_test_run(self, uuid, name, started_at, framework):
+        test_run_v1["uuid"] = uuid
+        test_run_v1["name"] = name
+        test_run_v1["startedAt"] = started_at
+        test_run_v1["framework"] = framework
+        return self.api.send_post(ZafiraClient.TEST_RUNS_PATH_V1, test_run_v1, headers=self.init_auth_headers(),
                                   default_err_msg="Unable to start test run")
 
+
     def update_test_run(self, test_run):
         return self.api.send_put(ZafiraClient.TEST_RUNS_PATH, test_run, headers=self.init_auth_headers(),
                                  default_err_msg="Unable to start test run")
