@@ -1,3 +1,4 @@
+import datetime
 import logging
 import time
 import pytest
@@ -77,12 +78,11 @@ class PyTestZafiraListener(BaseZafiraListener):
     Contains hook implementations
     """
 
+    FRAMEWORK = 'pytest'
+
     def __init__(self, state):
         super().__init__(state)
 
-        # self.state.CONFIG = "<config><arg unique='false'><key>env</key><value>API " \
-        #                     + Context.get_gui_parameter(Parameter.BROWSER).upper() + "</value></arg></config>"
-
     @pytest.hookimpl
     def pytest_sessionstart(self, session):
         """
@@ -92,23 +92,29 @@ class PyTestZafiraListener(BaseZafiraListener):
         if not self.initialized:
             return
         try:
-            self.state.test_suite = self.state.zc.create_test_suite(
-                self.state.user["id"], self.state.suite_name, 'filename'
-            ).json()
-            self.state.job = self.state.zc.create_job(
-                self.state.user["id"],
-                self.state.job_name,
-                self.state.job_url,
-                "jenkins_host"
-            ).json()
+            # self.state.test_suite = self.state.zc.create_test_suite(
+            #     self.state.user["id"], self.state.suite_name, 'filename'
+            # ).json()
+            # self.state.job = self.state.zc.create_job(
+            #     self.state.user["id"],
+            #     self.state.job_name,
+            #     self.state.job_url,
+            #     "jenkins_host"
+            # ).json()
+            # self.state.test_run = self.state.zc.start_test_run(
+            #     self.state.job["id"],
+            #     self.state.test_suite["id"],
+            #     0
+            #     # ,
+            #     # config=self.state.CONFIG
+            # ).json()
+            # self.state.ci_run_id = self.state.test_run.get('ciRunId')
             self.state.test_run = self.state.zc.start_test_run(
-                self.state.job["id"],
-                self.state.test_suite["id"],
-                0
-                # ,
-                # config=self.state.CONFIG
-            ).json()
-            self.state.ci_run_id = self.state.test_run.get('ciRunId')
+                uuid.uuid4(),
+                self.state.suite_name,
+                datetime.datetime.now(),
+                self.FRAMEWORK
+            )
         except Exception as e:
             self.state.is_enabled = False
             logging.error("Undefined error during test run registration! {}".format(e))
